@@ -4,6 +4,7 @@ import tkinter.filedialog as fd
 from tkinter import colorchooser
 from PIL import Image
 import os
+import sys
 import logging
 from pymedphys import gamma
 
@@ -62,7 +63,15 @@ class Options(ctk.CTkTabview):
 
                 
         self.graphlist = ScrollFrame(self.dataframe1)
-        path = os.path.join(os.path.dirname(os.path.abspath(__file__)),"..","resources", "images")
+        
+        def resource_path(relative_path):
+            """ Get absolute path to resource, works for dev and for PyInstaller """
+            if hasattr(sys, '_MEIPASS'):
+                return os.path.join(sys._MEIPASS, "TopasGraphSim", relative_path)
+
+            return os.path.join(os.path.dirname(os.path.abspath(__file__)), os.pardir, os.pardir, os.pardir,  relative_path) 
+        
+        path = resource_path(os.path.join("topasgraphsim", "src", "resources", "images"))
         self.uparrowimage = ctk.CTkImage(Image.open(os.path.join(path,"uparrow.png")), size=(20,20))
         self.downarrowimage = ctk.CTkImage(Image.open(os.path.join(path,"downarrow.png")), size=(20,20))
         self.uparrow = ctk.CTkButton(self.dataframe1, text="",image=self.uparrowimage, width=20, command = lambda: self.change_order("up"))
@@ -663,14 +672,14 @@ class Options(ctk.CTkTabview):
         
         root = self.parent.master.master.parent        
         window = ctk.CTkToplevel(root)
-        window.wm_attributes("-toolwindow", True)
-        window.geometry(f"180x120+{root.winfo_rootx()+root.winfo_width()//2-90}+{root.winfo_rooty()+root.winfo_height()//2-60}")
+        window.overrideredirect(True)
+        window.geometry(f"150x142+{root.winfo_rootx()+root.winfo_width()//2-75}+{root.winfo_rooty()+root.winfo_height()//2-71}")
         window.title("")
         
         def move(event):
             window.lift()
             entry.focus()
-            window.geometry(f"180x120+{root.winfo_rootx()+root.winfo_width()//2-90}+{root.winfo_rooty()+root.winfo_height()//2-60}")
+            window.geometry(f"150x142+{root.winfo_rootx()+root.winfo_width()//2-75}+{root.winfo_rooty()+root.winfo_height()//2-71}")
         
         def submit():
             self.newtabname = entry.get()
@@ -703,13 +712,18 @@ class Options(ctk.CTkTabview):
             self.parent.master.master._segmented_button.set(tab)
             self.parent.master.master._draw()
             return
-        
+        def close():
+            window.destroy()
+            
+        window.columnconfigure(0, weight=1)
+        closebutton = ctk.CTkButton(window, text=" X ", command=close, width=2, height=1, font=("Bahnschrift", 12))
+        closebutton.grid(row=0, column=0, sticky="ne", padx=(0, 4), pady=(4, 4))
         textlabel = ctk.CTkLabel(window, text=Text().newtabname[self.lang], font=("Bahnschrift", 16))
-        textlabel.pack(padx=5, pady=5, fill="x", expand=True)
+        textlabel.grid(row=1, column=0, sticky="nsew", padx=5, pady=5)
         entry = ctk.CTkEntry(window, takefocus=True)
         submitbutton = ctk.CTkButton(window, text="OK", command=submit, width=30, font=("Bahnschrift", 12))
-        entry.pack(fill="x", expand=True, padx=5, pady=5)
-        submitbutton.pack(padx=5, pady=5)
+        entry.grid(row=2, column=0, sticky="nsew", padx=5, pady=5)
+        submitbutton.grid(row=3, column=0, sticky="ns", padx=5, pady=5)
         entry.focus()
         window.bind("<Configure>", move)
         window.bind("<Escape>", lambda event: window.destroy())
