@@ -25,13 +25,21 @@ class TopasGraphSim(Tk):
         super().__init__()
         
         self.appname = "TopasGraphSim"
-        self.version = "23.1.0"
+        self.version = "23.1.2"
         self.author = "Sebastian Schäfer"
         self.affiliation = "UK Halle\nMLU Halle-Wittenberg\nUK Hamburg-Eppendorf"
         self.title(f"{self.appname} - v.{self.version}")
         self.lang = ctk.StringVar()
         self.lang.set(ProfileHandler().get_attribute("language"))
-        self.iconpath = os.path.join(os.path.dirname(__file__), "src", "resources","images", "icon.ico")
+            
+        def resource_path(relative_path):
+            """ Get absolute path to resource, works for dev and for PyInstaller """
+            if hasattr(sys, '_MEIPASS'):
+                return os.path.join(sys._MEIPASS, "TopasGraphSim", relative_path)
+
+            return os.path.join(os.path.dirname(os.path.abspath(__file__)), os.pardir, relative_path)
+        
+        self.iconpath = resource_path(os.path.join("topasgraphsim", "src", "resources","images", "icon.ico"))
         self.iconbitmap(self.iconpath)
         
         self.colorscheme = ctk.StringVar(value=ProfileHandler().get_attribute("color_scheme"))
@@ -50,17 +58,7 @@ class TopasGraphSim(Tk):
         width = screen_width // 2
         height = screen_height // 2
         self.minsize(width, height)
-        self.pack_propagate(False)
-        
-        
-        self.state(ProfileHandler().get_attribute("state"))
-        try:
-            self.geometry(ProfileHandler().get_attribute("geometry"))
-        except Exception:
-            x = screen_width // 2 - width // 2
-            y = screen_height // 2 - height // 2
-            self.geometry(f"{width}x{height}+{x-25}+{y}")
-            
+        self.pack_propagate(False)            
            
         self.protocol("WM_DELETE_WINDOW", self.exit)
         for i in sys.argv[1:]:
@@ -68,6 +66,13 @@ class TopasGraphSim(Tk):
                 self.frame.add_file(i)
         CheckForUpdates()
         self.mainloop()
+        self.state(ProfileHandler().get_attribute("state"))
+        try:
+            self.geometry(ProfileHandler().get_attribute("geometry"))
+        except Exception:
+            x = screen_width // 2 - width // 2
+            y = screen_height // 2 - height // 2
+            self.geometry(f"{width}x{height}+{x-25}+{y}")
  
     def settings(self):
         try:
@@ -170,12 +175,12 @@ class TopasGraphSim(Tk):
 
             self.bell()
             window = ctk.CTkToplevel(self)
-            window.wm_attributes("-toolwindow", True)
+            window.overrideredirect(True)
             window.title("")
             
             def move(event):
                 window.lift()
-                window.geometry(f"200x100+{self.winfo_rootx()+self.winfo_width()//2-100}+{self.winfo_rooty()+self.winfo_height()//2-50}")
+                window.geometry(f"200x120+{self.winfo_rootx()+self.winfo_width()//2-100}+{self.winfo_rooty()+self.winfo_height()//2-60}")
             
             def submit():
                 window.destroy()
@@ -183,16 +188,19 @@ class TopasGraphSim(Tk):
             
             def cancel():
                 window.destroy()
+                
             
-            window.rowconfigure(0, weight=1)
+            window.rowconfigure(1, weight=1)
             window.columnconfigure(0, weight=1)
             window.columnconfigure(1, weight=1)
+            closebutton = ctk.CTkButton(window, text=" X ", command=cancel, width=2, height=1, font=("Bahnschrift", 12))
+            closebutton.grid(row=0, column=1, sticky="ne", padx=(0, 4), pady=(4, 4))
             textlabel = ctk.CTkLabel(window, text=Text().unsavedchanges1[self.lang.get()], font=("Bahnschrift", 16))
             submitbutton = ctk.CTkButton(window, text=Text().yes[self.lang.get()], command=submit, width=40, font=("Bahnschrift", 12))
             cancelbutton = ctk.CTkButton(window, text=Text().no[self.lang.get()], command=cancel, width = 40, font=("Bahnschrift", 12))
-            textlabel.grid(row=0, columnspan=2, padx=5, pady=5, sticky="nsew")
-            submitbutton.grid(row=1, column=0, padx=5, pady=5, sticky="nsew")
-            cancelbutton.grid(row=1, column=1, padx=5, pady=5, sticky="nsew")
+            textlabel.grid(row=1, columnspan=2, padx=5, pady=5, sticky="nsew")
+            submitbutton.grid(row=2, column=0, padx=5, pady=5, sticky="nsew")
+            cancelbutton.grid(row=2, column=1, padx=5, pady=5, sticky="nsew")
             window.bind("<Configure>", move)
             window.bind("<Escape>", lambda event: window.destroy())
             window.bind("<Return>", lambda event: submit())
